@@ -1,6 +1,6 @@
 #include "spvm_native.h"
 
-#ifdef _WIN32
+#if defined(_WIN32)
   #include <winsock2.h>
 #else
   #include <sys/ioctl.h>
