@@ -5,7 +5,7 @@
 
 #include <assert.h>
 
-#ifdef _WIN32
+#if defined(_WIN32)
   #include <ws2tcpip.h>
   #include <winsock2.h>
   #include <io.h>
