@@ -10,7 +10,7 @@ static const char* FILE_NAME = "Sys/User/Passwd.c";
 
 int32_t SPVM__Sys__User__Passwd__pw_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_name\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -26,7 +26,7 @@ int32_t SPVM__Sys__User__Passwd__pw_name(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__User__Passwd__pw_passwd(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_passwd\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -42,7 +42,7 @@ int32_t SPVM__Sys__User__Passwd__pw_passwd(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__User__Passwd__pw_uid(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_uid\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -58,7 +58,7 @@ int32_t SPVM__Sys__User__Passwd__pw_uid(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__User__Passwd__pw_gid(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_gid\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -74,7 +74,7 @@ int32_t SPVM__Sys__User__Passwd__pw_gid(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__User__Passwd__pw_gecos(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_gecos\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -90,7 +90,7 @@ int32_t SPVM__Sys__User__Passwd__pw_gecos(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__User__Passwd__pw_dir(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_dir\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
@@ -106,7 +106,7 @@ int32_t SPVM__Sys__User__Passwd__pw_dir(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__User__Passwd__pw_shell(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-#ifdef _WIN32
+#if defined(_WIN32)
   env->die(env, stack, "The method \"pw_shell\" in the class \"Sys::User::Passwd\" is not supported on this system", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
